==> Pilot-Lib-0.0.7.tar.gz: Pilot-Lib-0.0.7/pilot_lib/model.py <==

import utils

def user_mixin(db):
    """
    UserMixin
    :params db: active_sqlalchemy
    """
    class UserMixin(object):
        """An admin user capable of viewing reports.

        :param str email: email address of user
        :param str password: encrypted password for the user

        """

        ROLE_USER = "USER"
        ROLE_ADMIN = "ADMIN"
        ROLE_SUPERADMIN = "SUPERADMIN"

        STATUS_ACTIVE = "ACTIVE"
        STATUS_SUSPENDED = "SUSPENDED"

        all_roles = [ROLE_USER, ROLE_ADMIN, ROLE_SUPERADMIN]
        all_status = [STATUS_ACTIVE, STATUS_SUSPENDED]

        email = db.Column(db.String(75), index=True, unique=True)
        email_confirmed = db.Column(db.Boolean, default=False)
        password_hash = db.Column(db.String(250))
        require_password_change = db.Column(db.Boolean, default=False)
        reset_password_token = db.Column(db.String(100))
        name = db.Column(db.String(250))
        role = db.Column(db.String(25), default=ROLE_USER)
        status = db.Column(db.String(25), default=STATUS_ACTIVE)
        is_loggedin = db.Column(db.Boolean, default=False)

        # ------ FLASK-LOGIN REQUIRED METHODS ----------------------------------

        def is_active(self):
            """True, as all users are active."""
            return True

        def get_id(self):
            """Return the id """
            return self.id

        def is_authenticated(self):
            """Return True if the user is authenticated."""
            return True

        def is_anonymous(self):
            """ False, as anonymous users aren't supported."""
            return False
        # ---------- END FLASK-LOGIN REQUIREMENTS ------------------------------

        @classmethod
        def get_by_email(cls, email):
            """
            Find by email. Useful for logging in users
            """
            return cls.all().filter(cls.email == email).first()

        @classmethod
        def find_by_email(cls, email):
            """ @deprecated, use get_by_email"""
            return cls.get_by_email(email)

        @classmethod
        def register(cls, email, password=None, name=None, role=ROLE_USER):
            """
            Register a new user
            """
            account = cls.get_by_email(email)
            if account:
                raise UserWarning("User exists already")
            else:
                account = cls.create(email=email, name=name, role=role)
                if password:
                    account.set_password(password)
                return account

        def password_matched(self, password):
            """
            Check if the password matched the hash
            :returns bool:
            """
            return utils.verify_hash_string(password, self.password_hash)

        def set_password(self, password):
            """
            Encrypt the password and save it in the DB
            """
            self.update(password_hash=utils.hash_string(password))

        def set_random_password(self):
            """
            Set a random password, saves it and return the readable string
            :returns string:
            """
            password = utils.generate_random_string()
            self.set_password(password)
            return password

        def set_require_password_change(self, req=True):
            """
            Set the require password change ON/OFF
            :params req: bool
            """
            self.update(require_password_change=req)

        def set_role(self, role):
            """
            Set account role
            """
            self.update(role=role)

    return UserMixin

==> Pilot-Lib-0.0.14.tar.gz: Pilot-Lib-0.0.14/pilot_lib/model.py <==

import utils

def user_mixin(db):
    """
    UserMixin
    :params db: active_sqlalchemy
    """
    class UserMixin(object):
        """An admin user capable of viewing reports.

        :param str email: email address of user
        :param str password: encrypted password for the user

        """

        ROLE_USER = "USER"
        ROLE_ADMIN = "ADMIN"
        ROLE_SUPERADMIN = "SUPERADMIN"

        STATUS_ACTIVE = "ACTIVE"
        STATUS_SUSPENDED = "SUSPENDED"

        all_roles = [ROLE_USER, ROLE_ADMIN, ROLE_SUPERADMIN]
        all_status = [STATUS_ACTIVE, STATUS_SUSPENDED]

        email = db.Column(db.String(75), index=True, unique=True)
        email_confirmed = db.Column(db.Boolean, default=False)
        password_hash = db.Column(db.String(250))
        require_password_change = db.Column(db.Boolean, default=False)
        reset_password_token = db.Column(db.String(100))
        name = db.Column(db.String(250))
        role = db.Column(db.String(25), default=ROLE_USER)
        status = db.Column(db.String(25), default=STATUS_ACTIVE)
        is_loggedin = db.Column(db.Boolean, default=False)
        profile_pic_url = db.Column(db.String(250))

        # ------ FLASK-LOGIN REQUIRED METHODS ----------------------------------

        def is_active(self):
            """True, as all users are active."""
            return True

        def get_id(self):
            """Return the id """
            return self.id

        def is_authenticated(self):
            """Return True if the user is authenticated."""
            return True

        def is_anonymous(self):
            """ False, as anonymous users aren't supported."""
            return False
        # ---------- END FLASK-LOGIN REQUIREMENTS ------------------------------

        @classmethod
        def get_by_email(cls, email):
            """
            Find by email. Useful for logging in users
            """
            return cls.all().filter(cls.email == email).first()

        @classmethod
        def find_by_email(cls, email):
            """ @deprecated, use get_by_email"""
            return cls.get_by_email(email)

        @classmethod
        def new(cls, email, password=None, **kwargs):
            """
            Register a new user
            """
            account = cls.get_by_email(email)
            if account:
                raise UserWarning("User exists already")
            account = cls.create(email=email)
            if password:
                account.set_password(password)
            if "role" not in kwargs:
                kwargs["role"] = cls.ROLE_USER
            if kwargs:
                account.update(**kwargs)
            return account

        def password_matched(self, password):
            """
            Check if the password matched the hash
            :returns bool:
            """
            return utils.verify_hash_string(password, self.password_hash)

        def set_password(self, password):
            """
            Encrypt the password and save it in the DB
            """
            self.update(password_hash=utils.hash_string(password))

        def set_random_password(self):
            """
            Set a random password, saves it and return the readable string
            :returns string:
            """
            password = utils.generate_random_string()
            self.set_password(password)
            return password

        def set_require_password_change(self, req=True):
            """
            Set the require password change ON/OFF
            :params req: bool
            """
            self.update(require_password_change=req)

        def set_role(self, role):
            """
            Set account role
            """
            self.update(role=role)

    return UserMixin
